@@ -1,84 +1,22 @@
 import numpy as np
-import k3d
-from k3d.plot import Plot
-from k3d.objects import Group, Line, Points
 from abc import ABCMeta, abstractmethod
-from typing import Union, NewType
-
-SkeletonPlot = NewType('SkeletonPlot', Union[Plot, type(None)])
-Color = NewType('Color', Union[str, int])
-Colors = NewType('Colors', Union[list[Color], type(None)])
-
-
-class Skeleton:
-    def __init__(self, joint_coordinates: np.ndarray, part_size: float, color: Color):
-        self.joint_coordinates: np.ndarray = joint_coordinates
-        self.part_size: float = part_size
-        self.color: Color = color
 
 
 class JointSet(metaclass=ABCMeta):
     def __init__(self):
-        self.names = None
-        self.number_of_joints = None
-        self.limb_graph = None
-        self.left_joint_indices = None
-        self.right_joint_indices = None
-        self.center_joint_indices = None
-        self.left_line_indices = None
-        self.right_line_indices = None
-        self.center_line_indices = None
+        self.names: np.ndarray = np.array([])
+        self.number_of_joints: int = 0
+        self.limb_graph: list[tuple[int, int]] = []
+        self.left_joint_indices: list[int] = []
+        self.right_joint_indices: list[int] = []
+        self.center_joint_indices: list[int] = []
+        self.left_line_indices: list[int] = []
+        self.right_line_indices: list[int] = []
+        self.center_line_indices: list[int] = []
 
     @abstractmethod
     def convert_to_common_14(self):
-        return None
-
-    def generate_skeleton_object(self, skeleton: Skeleton) -> Group:
-        assert skeleton.joint_coordinates.shape == (self.number_of_joints, 3)
-        skeleton_joint_colors, skeleton_line_colors = self.__get_skeleton_colors(skeleton)
-        skeleton_joint_points = self.__create_skeleton_joint_points(skeleton, skeleton_joint_colors)
-        skeleton_joint_lines = self.__create_skeleton_lines(skeleton, skeleton_line_colors)
-        skeleton_object: Group = Group()
-        skeleton_object += skeleton_joint_points
-        for line in skeleton_joint_lines:
-            skeleton_object += line
-        return skeleton_object
-
-    def __get_skeleton_colors(self, skeleton: Skeleton) -> tuple[np.ndarray, np.ndarray]:
-        if skeleton.color == 'default':
-            joint_colors = np.zeros(shape=(self.number_of_joints,), dtype=int)
-            line_colors = np.zeros(shape=(self.number_of_joints - 1, ), dtype=int)
-            joint_colors[self.left_joint_indices] = 0xFF0000
-            joint_colors[self.right_joint_indices] = 0x0000FF
-            joint_colors[self.center_joint_indices] = 0xFFFFFF
-            line_colors[self.left_line_indices] = 0xFF0000
-            line_colors[self.right_line_indices] = 0x0000FF
-            line_colors[self.center_line_indices] = 0xFFFFFF
-            return joint_colors, line_colors
-        else:
-            return [skeleton.color] * self.number_of_joints, [skeleton.color] * (self.number_of_joints - 1)
-
-    def __create_skeleton_lines(self, skeleton: Skeleton, skeleton_line_colors: np.ndarray):
-        return [self.__create_line_between_joints(
-            start=skeleton.joint_coordinates[self.limb_graph[i][0]],
-            end=skeleton.joint_coordinates[self.limb_graph[i][1]],
-            width=skeleton.part_size / 4.0,
-            color=int(skeleton_line_colors[i])
-        ) for i in range(len(self.limb_graph))]
-
-    @staticmethod
-    def __create_line_between_joints(start: float, end: float, width: float, color: int) -> Line:
-        return k3d.line(
-            vertices=[start, end], shader='mesh',
-            width=width, color=color
-        )
-
-    @staticmethod
-    def __create_skeleton_joint_points(skeleton: Skeleton, skeleton_joint_colors: np.ndarray) -> Points:
-        return k3d.points(
-            positions=skeleton.joint_coordinates, point_size=skeleton.part_size,
-            shader='mesh', colors=skeleton_joint_colors
-        )
+        return self
 
 
 class MuPoTSJoints(JointSet):
@@ -102,8 +40,8 @@ class MuPoTSJoints(JointSet):
             (7, 6), (6, 5), (5, 1),         # Left arm
         ]
         self.number_of_joints = 17
-        self.left_joint_indices = [2, 3, 4, 8, 9, 10]
-        self.right_joint_indices = [5, 6, 7, 11, 12, 13]
+        self.left_joint_indices = [5, 6, 7, 11, 12, 13]
+        self.right_joint_indices = [2, 3, 4, 8, 9, 10]
         self.center_joint_indices = [0, 1, 14, 15, 16]
         self.left_line_indices = [3, 4, 5, 13, 14, 15]
         self.right_line_indices = [0, 1, 2, 10, 11, 12]
